<?php
/**
 * houston-theme functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package houston-theme
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function houston_theme_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on houston-theme, use a find and replace
		* to change 'houston-theme' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'houston-theme', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'header-menu' => esc_html__( 'Header Menu', 'houston-theme' ),
			'footer-menu' => esc_html__( 'Footer Menu', 'houston-theme' ),
			'policy-menu' => esc_html__( 'Policy Menu', 'houston-theme' ),
			'seo-menu' => esc_html__( 'SEO Menu', 'houston-theme' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'houston_theme_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action( 'after_setup_theme', 'houston_theme_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function houston_theme_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'houston_theme_content_width', 640 );
}
add_action( 'after_setup_theme', 'houston_theme_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function houston_theme_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'houston-theme' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'houston-theme' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'houston_theme_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function houston_theme_scripts() {

	// wp_enqueue_style('houston-theme-layout-css', get_template_directory_uri() . '/assets/css/layout.css', array(), '20151215');
	wp_enqueue_style('houston-theme-layout-min-css', get_template_directory_uri() . '/assets/css/layout.min.css', array(), '20151215');
	wp_enqueue_style('houston-theme-fancybox-min', get_template_directory_uri() . '/assets/css/jquery.fancybox.min.css', array(), '20151215');

	wp_enqueue_style( 'houston-theme-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_enqueue_script('jquery');
	wp_style_add_data( 'houston-theme-style', 'rtl', 'replace' );

	wp_enqueue_script('houston-theme-layout-js', get_template_directory_uri() . '/assets/js/layout.js', array(), '20151215', true);
	wp_enqueue_script('houston-theme-slick', get_template_directory_uri() . '/assets/js/slick.min.js', array(), '20151215', true);
	wp_enqueue_script('houston-theme-simplebar-js', get_template_directory_uri() . '/assets/js/simplebar.js', array(), '20151215', true);
	wp_enqueue_script('houston-theme-fancybox-min', get_template_directory_uri() . '/assets/js/jquery.fancybox.min.js', array(), '20151215', true);
	wp_enqueue_script('houston-theme-font-awesome-min', get_template_directory_uri() . '/assets/js/font-awesome.min.js', array(), '20151215', true);
	wp_enqueue_script('houston-theme-custom', get_template_directory_uri() . '/assets/js/custom.js', array(), rand(1000, 10000), true);
	wp_localize_script('houston-theme-custom', 'custom_call', ['ajaxurl' => admin_url('admin-ajax.php'), 'homeurl' => home_url()]);
	
	wp_enqueue_script( 'houston-theme-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'houston_theme_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

// Filter the output of logo to fix Googles Error about itemprop logo
add_filter( 'get_custom_logo', 'change_html_custom_logo' );
function change_html_custom_logo() {
    $custom_logo_id = get_theme_mod( 'custom_logo' );
	$site_name = get_bloginfo( 'name' );
    $html = sprintf( '<a href="%1$s" class="custom-logo-link" rel="home" title="'.$site_name.'" >%2$s</a>',
            esc_url( home_url( '/' ) ),
            wp_get_attachment_image( $custom_logo_id, 'full', false, array(
                'class'    => 'custom-logo',
				'alt'  	   => $site_name,
            ) )
        );
    return $html;   
}

add_action('wp_ajax_gallery_tabbing','gallery_image_tabbing');
add_action( 'wp_ajax_nopriv_gallery_tabbing', 'gallery_image_tabbing' );

function gallery_image_tabbing() {	
	$frontpage_id = get_option( 'page_on_front' );

	$index = $_POST['id'];
	
	$pageid = $_POST['pageid'];

	if($pageid == $frontpage_id ){
		if( have_rows('photo_gallery', $frontpage_id) ){?>
			<span class="spinner"><i class="fas fa-spinner fa-spin" aria-hidden="true"></i></span>
			<div class="row gallery-slider">
				<?php
				while( have_rows('photo_gallery', $frontpage_id) ){
					the_row();
					
					if(get_row_index() == $index){
						$images = get_sub_field('gallery_image');
						if(!empty($images)){
							$i = 1;
							foreach ($images as $image) { ?>
								<div class="col-lg-4">
									<div class="gallery-image">
										<a href="<?php echo $image['url']; ?>" data-fancybox="gallery-image" title="Gallery-image-<?php echo $i; ?>">
											<div class="back-img" style="background-image: url('<?php echo $image['url']; ?>');"></div>
										</a>
									</div>
								</div>
								<?php
								$i++;
							}
						}
					}
				}?>
			</div>
			<?php
		}
	}else{
		if( have_rows('service_gallery', $pageid) ){?>
			<span class="spinner"><i class="fas fa-spinner fa-spin" aria-hidden="true"></i></span>
			<div class="row gallery-slider">
				<?php
				while( have_rows('service_gallery', $pageid) ){
					the_row();
					
					if(get_row_index() == $index){
						$images = get_sub_field('service_gallery_image');
						if( !empty($images) ){
							$i = 1;
							foreach ($images as $image) { ?>
								<div class="col-lg-4">
									<div class="gallery-image">
										<a href="<?php echo $image['url']; ?>" data-fancybox="gallery-image" title="Gallery-image-<?php echo $i; ?>">
											<div class="back-img" style="background-image: url('<?php echo $image['url']; ?>');"></div>
										</a>
									</div>
								</div>
								<?php
								$i++;
							}
						}
					}
				}?>
			</div>
			<?php
		}
	}
die;
}
